pub struct BpmnActivityRunState {
pub type: Type,
}Expand description
BpmnActivityRunState : lifecycle of a single dispatched activity, tagged by type
Fields
type: TypeImplementations
Sourceimpl BpmnActivityRunState
impl BpmnActivityRunState
Sourcepub fn new(type: Type) -> BpmnActivityRunState
pub fn new(type: Type) -> BpmnActivityRunState
lifecycle of a single dispatched activity, tagged by type