pub struct BpmnMigrationCheck {
pub from_version: i64,
pub to_version: i64,
pub bpmn_flow_path: String,
pub eligible: bool,
pub blockers: Vec<BpmnMigrationBlocker>,
}Expand description
BpmnMigrationCheck : Whether an instance pinned to from_version may be repinned to to_version, and if not, why. A property of the pair, not of an instance.
Fields
from_version: i64to_version: i64bpmn_flow_path: Stringeligible: boolblockers: Vec<BpmnMigrationBlocker>Implementations
Sourceimpl BpmnMigrationCheck
impl BpmnMigrationCheck
Sourcepub fn new(
from_version: i64,
to_version: i64,
bpmn_flow_path: String,
eligible: bool,
blockers: Vec<BpmnMigrationBlocker>,
) -> BpmnMigrationCheck
pub fn new( from_version: i64, to_version: i64, bpmn_flow_path: String, eligible: bool, blockers: Vec<BpmnMigrationBlocker>, ) -> BpmnMigrationCheck
Whether an instance pinned to from_version may be repinned to to_version, and if not, why. A property of the pair, not of an instance.