Module delegate_key_kind

Module delegate_key_kind 

Enums

DelegateKeyKind
DelegateKeyKind : Which BPMN dialect attribute the delegate key was read from. Part of the lookup key, not decoration: in Flowable, flowable:class=\"foo\" and flowable:delegateExpression=\"${foo}\" are different constructs, and letting a binding for one satisfy a reference to the other would be a silent semantic mix. Which BPMN dialect attribute the delegate key was read from. Part of the lookup key, not decoration: in Flowable, flowable:class=\"foo\" and flowable:delegateExpression=\"${foo}\" are different constructs, and letting a binding for one satisfy a reference to the other would be a silent semantic mix.