Module process_status_value

Module process_status_value 

Enums

ProcessStatusValue
ProcessStatusValue : overall status of one process instance, as surfaced to the frontend overall status of one process instance, as surfaced to the frontend