pub enum ProcessStatusValue {
Running,
Completed,
Failed,
Suspended,
Canceled,
}Expand description
ProcessStatusValue : overall status of one process instance, as surfaced to the frontend overall status of one process instance, as surfaced to the frontend
Variants