Structs
- Unbound
Delegate Checklist Entry - UnboundDelegateChecklistEntry : One row of the unbound-delegate checklist – a distinct
(key_kind, key)with no binding row yet, and every place it is referenced from.
(key_kind, key) with no binding row yet, and every place it is referenced from.