pub async fn restart_worker_pool(
configuration: &Configuration,
worker_pool: &str,
) -> Result<String, Error<RestartWorkerPoolError>>Expand description
Send a restart signal to all workers in the specified worker pool. Workers will gracefully shut down and are expected to be restarted by their supervisor. Requires devops role.